local PI = GLOBAL.PI

local rain_a = GetModConfigData("autumn")
local rain_s = GetModConfigData("spring")

local function postinit(self)
	--local old = self.UpdateDynamicPrecip --well I'm afraid it's not *that* easy
	self.UpdateDynamicPrecip = function(self,dt)
		local percent_season = self:GetPercentSeason()
		local atmo_moisture_rate = self.base_atmo_moisture_rate
		
		if self:IsWinter() then
			if self.UpdateWinterPrecipPostInit then --little present to other modders :P
				self.UpdateWinterPrecipPostInit(self,dt)
			else
				if self:GetDaysIntoSeason() > 1 and self:GetDaysIntoSeason() < 3 then
					atmo_moisture_rate = 50
				end
			end
		elseif self:IsAutumn() then --this is the only "new" part
			local p = 1-math.sin(PI*percent_season)
			local min_autumn_rate = rain_a and 3 or .25
			local max_autumn_rate = rain_a and 3.75 or 1
			atmo_moisture_rate = (min_autumn_rate + p * (max_autumn_rate - min_autumn_rate)) * self.base_atmo_moisture_rate
		elseif self:IsSpring() then
			local p = 1-math.sin(PI*percent_season)
			local min_spring_rate = rain_s and 3 or .25
			local max_spring_rate = rain_s and 3.75 or 1
			atmo_moisture_rate = (min_spring_rate + p * (max_spring_rate - min_spring_rate)) * self.base_atmo_moisture_rate
		else --end of "new" part
			if self.UpdateSummerPrecipPostInit then
				self.UpdateSummerPrecipPostInit(self,dt) --little present to other modders
			else
				local p = 1-math.sin(PI*percent_season)
				local min_summer_rate = .10
				local max_summer_rate = .5
				atmo_moisture_rate = (min_summer_rate + p * (max_summer_rate - min_summer_rate)) * self.base_atmo_moisture_rate
			end
		end
		
		if self.PrecipDeltaPostInit then
			self.PrecipDeltaPostInit(self,dt) --little present to other modders
		else
			local RATE_SCALE = 10
			if self.precip then
				self.atmo_moisture = self.atmo_moisture - self.precip_rate*dt*RATE_SCALE
				if self.atmo_moisture < 0 then
					self.atmo_moisture = 0
				end

				if self.atmo_moisture < self.moisture_floor then
					self:StopPrecip()
				end

				local percent = math.max(0, math.min(1, (self.atmo_moisture - self.moisture_floor) / (self.moisture_limit - self.moisture_floor)))
				local min_rain = .1
				self.precip_rate = (min_rain + (1-min_rain)*math.sin(percent*PI))
				self.precip_rate = math.clamp(self.precip_rate, 0, self.peak_precip_intensity)
			else
				self.atmo_moisture = math.min(self.moisture_limit, self.atmo_moisture + atmo_moisture_rate*dt)
				self.precip_rate = 0
				
				if self.atmo_moisture >= self.moisture_limit then
					self.atmo_moisture = self.moisture_limit
					self:StartPrecip()
				end
			end
		end
	end
end

AddComponentPostInit("seasonmanager",postinit)